@@ -1,10 +1,8 @@
-context("readxl_example")
-
 test_that("NULL path returns names of example files", {
   example_files <- readxl_example()
   expect_true("datasets.xls" %in% example_files)
   expect_true("datasets.xlsx" %in% example_files)
-  expect_is(example_files, "character")
+  expect_true(is.character(example_files))
 })
 
 test_that("providing example file name returns full path", {
