@@ -1,5 +1,3 @@
-context("n_max")
-
 test_that("simple use of n_max works and does not affect col name reading", {
   ## xlsx
   df <- read_excel(test_sheet("iris-excel-xlsx.xlsx"), n_max = 1)
@@ -21,14 +19,16 @@ test_that("simple use of n_max works and does not affect col name reading", {
 test_that("n_max = 0 and col_names = FALSE gives empty tibble", {
   ## xlsx
   df <- read_excel(
-    test_sheet("skipping.xlsx"), sheet = "two_occupied_rows",
+    test_sheet("skipping.xlsx"),
+    sheet = "two_occupied_rows",
     n_max = 0, col_names = FALSE
   )
   expect_identical(df, tibble::tibble())
 
   ## xls
   df <- read_excel(
-    test_sheet("skipping.xls"), sheet = "two_occupied_rows",
+    test_sheet("skipping.xls"),
+    sheet = "two_occupied_rows",
     n_max = 0, col_names = FALSE
   )
   expect_identical(df, tibble::tibble())
@@ -37,14 +37,16 @@ test_that("n_max = 0 and col_names = FALSE gives empty tibble", {
 test_that("n_max is upper bound on nrows, if it causes trailing blank row", {
   ## xlsx
   df <- read_excel(
-    test_sheet("skipping.xlsx"), sheet = "two_occupied_rows",
+    test_sheet("skipping.xlsx"),
+    sheet = "two_occupied_rows",
     n_max = 3
   )
   expect_identical(nrow(df), 2L)
 
   ## xls
   df <- read_excel(
-    test_sheet("skipping.xls"), sheet = "two_occupied_rows",
+    test_sheet("skipping.xls"),
+    sheet = "two_occupied_rows",
     n_max = 3
   )
   expect_identical(nrow(df), 2L)
@@ -53,13 +55,15 @@ test_that("n_max is upper bound on nrows, if it causes trailing blank row", {
 test_that("n_max can affect ncols, if prevents read of data in a col [xlsx]", {
   ## xlsx
   df <- read_excel(
-    test_sheet("skipping.xlsx"), sheet = "two_occupied_rows",
+    test_sheet("skipping.xlsx"),
+    sheet = "two_occupied_rows",
     n_max = 0
   )
   expect_identical(nrow(df), 0L)
   expect_identical(ncol(df), 1L)
   df <- read_excel(
-    test_sheet("skipping.xlsx"), sheet = "two_occupied_rows",
+    test_sheet("skipping.xlsx"),
+    sheet = "two_occupied_rows",
     skip = 1, n_max = 0
   )
   expect_identical(nrow(df), 0L)
@@ -69,13 +73,15 @@ test_that("n_max can affect ncols, if prevents read of data in a col [xlsx]", {
 test_that("n_max can affect ncols, if prevents read of data in a col [xls]", {
   ## xls
   df <- read_excel(
-    test_sheet("skipping.xls"), sheet = "two_occupied_rows",
+    test_sheet("skipping.xls"),
+    sheet = "two_occupied_rows",
     n_max = 0
   )
   expect_identical(nrow(df), 0L)
   expect_identical(ncol(df), 1L)
   df <- read_excel(
-    test_sheet("skipping.xls"), sheet = "two_occupied_rows",
+    test_sheet("skipping.xls"),
+    sheet = "two_occupied_rows",
     skip = 1, n_max = 0
   )
   expect_identical(nrow(df), 0L)
