@@ -1,5 +1,3 @@
-context("read_excel")
-
 test_that("can read sheets with inlineStr", {
   # Original source: http://our.componentone.com/wp-content/uploads/2011/12/TestExcel.xlsx
   # These appear to come from LibreOffice 4.2.7.2.
@@ -8,66 +6,76 @@ test_that("can read sheets with inlineStr", {
 })
 
 test_that("can read files with and without extension [xls]", {
-  file.copy(test_sheet("iris-excel-xls.xls"), "iris-xls-no-ending")
-  on.exit(file.remove("iris-xls-no-ending"))
+  iris_xls_no_ending <- withr::local_tempfile()
+  file.copy(test_sheet("iris-excel-xls.xls"), iris_xls_no_ending)
   iris_xls <- read_excel(test_sheet("iris-excel-xls.xls"))
-  iris_guess <- read_excel("iris-xls-no-ending")
-  iris_explicit <- read_xls("iris-xls-no-ending")
+  iris_guess <- read_excel(iris_xls_no_ending)
+  iris_explicit <- read_xls(iris_xls_no_ending)
   expect_equal(iris_xls, iris_guess)
   expect_equal(iris_xls, iris_explicit)
 })
 
 test_that("xlsx is not read as xls and vice versa", {
-  expect_error(
+  scrubfun <- function(x) {
+    sub("'?[^ ]*iris-excel-xlsx?[.]xlsx?'?", "'VOLATILE_FILEPATH'", x)
+  }
+  expect_snapshot(
+    error = TRUE,
     read_xls(test_sheet("iris-excel-xlsx.xlsx")),
-    "libxls error: Unable to open file"
+    transform = scrubfun
+  )
+  expect_snapshot(
+    error = TRUE,
+    read_xlsx(test_sheet("iris-excel-xls.xls")),
+    transform = scrubfun
   )
-  expect_error(read_xlsx(test_sheet("iris-excel-xls.xls")), "cannot be opened")
 })
 
 test_that("non-existent file throws error", {
-  expect_error(read_excel("foo"), "`path` does not exist")
+  expect_snapshot(
+    error = TRUE,
+    read_excel("foo")
+  )
 })
 
 test_that("read_excel catches invalid guess_max", {
-  expect_error(
-    read_excel(test_sheet("iris-excel-xlsx.xlsx"), guess_max = NA),
-    "`guess_max` must be a positive integer"
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("iris-excel-xlsx.xlsx"), guess_max = NA)
   )
-  expect_error(
-    read_excel(test_sheet("iris-excel-xlsx.xlsx"), guess_max = -1),
-    "`guess_max` must be a positive integer"
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("iris-excel-xlsx.xlsx"), guess_max = -1)
   )
-  expect_warning(
-    read_excel(test_sheet("iris-excel-xlsx.xlsx"), guess_max = Inf),
-    "`guess_max` is a very large value"
+  expect_snapshot(
+    out <- read_excel(test_sheet("iris-excel-xlsx.xlsx"), guess_max = Inf)
   )
-  expect_error(
-    read_excel(test_sheet("iris-excel-xlsx.xlsx"), guess_max = NULL),
-    "`guess_max` must be a positive integer"
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("iris-excel-xlsx.xlsx"), guess_max = NULL)
   )
-  expect_error(
-    read_excel(test_sheet("iris-excel-xlsx.xlsx"), guess_max = 1:2),
-    "`guess_max` must be a positive integer"
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("iris-excel-xlsx.xlsx"), guess_max = 1:2)
   )
 })
 
 test_that("read_excel catches invalid n_max", {
-  expect_error(
-    read_excel(test_sheet("iris-excel-xlsx.xlsx"), n_max = NA),
-    "`n_max` must be a positive integer"
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("iris-excel-xlsx.xlsx"), n_max = NA)
   )
-  expect_error(
-    read_excel(test_sheet("iris-excel-xlsx.xlsx"), n_max = -1),
-    "`n_max` must be a positive integer"
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("iris-excel-xlsx.xlsx"), n_max = -1)
   )
-  expect_error(
-    read_excel(test_sheet("iris-excel-xlsx.xlsx"), n_max = NULL),
-    "`n_max` must be a positive integer"
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("iris-excel-xlsx.xlsx"), n_max = NULL)
   )
-  expect_error(
-    read_excel(test_sheet("iris-excel-xlsx.xlsx"), n_max = 1:2),
-    "`n_max` must be a positive integer"
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("iris-excel-xlsx.xlsx"), n_max = 1:2)
   )
 })
 
@@ -78,16 +86,16 @@ test_that("xls with exactly 65536 rows does not enter infinite loop", {
 })
 
 test_that("sheet must be integer or string", {
-  expect_error(
-    read_excel(test_sheet("mtcars.xls"), sheet = TRUE),
-    "`sheet` must be either an integer or a string."
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("mtcars.xls"), sheet = TRUE)
   )
 })
 
 test_that("trim_ws must be a logical", {
-  expect_error(
-    read_excel(test_sheet("mtcars.xls"), trim_ws = "yes"),
-    "`trim_ws` must be either TRUE or FALSE"
+  expect_snapshot(
+    error = TRUE,
+    read_excel(test_sheet("mtcars.xls"), trim_ws = "yes")
   )
 })
 
@@ -109,14 +117,14 @@ test_that("non-ASCII filenames can be read", {
   expect_true(file.exists(tricky_xlsx_file))
   on.exit(file.remove(tricky_xls_file))
   on.exit(file.remove(tricky_xlsx_file))
-  expect_error_free(read_xls(tricky_xls_file))
-  expect_error_free(read_xlsx(tricky_xlsx_file))
+  expect_no_error(read_xls(tricky_xls_file))
+  expect_no_error(read_xlsx(tricky_xlsx_file))
 })
 
 test_that("styles and sharedStrings parts can be absent", {
-  expect_error_free(
+  expect_no_error(
     df <- read_xlsx(test_sheet("no-styles-or-sharedStrings-parts.xlsx"))
   )
   expect_identical(df$Language[1], "german")
   expect_true(all(df$Age > 0))
- })
+})
